@@ -20,7 +20,12 @@ from contextlib import contextmanager
 import numpy as np
 
 import astropy.units as u
-from astropy._erfa import obl06
+
+try:
+    from erfa import obl06
+except ModuleNotFoundError:
+    from astropy._erfa import obl06
+
 from astropy.constants import c as speed_of_light
 from astropy.coordinates import (
     HCRS,
