@@ -237,6 +237,8 @@ class JSOCClient(BaseClient):
         >>> res.wait(progress=True)   # doctest: +SKIP
 
     """
+    # Default number of max connections that the Downloader opens
+    default_max_conn = 2
 
     def search(self, *query, **kwargs):
         """
@@ -453,7 +455,7 @@ class JSOCClient(BaseClient):
         return requests
 
     def fetch(self, jsoc_response, path=None, progress=True, overwrite=False,
-              downloader=None, wait=True, sleep=10, max_conn=4, **kwargs):
+              downloader=None, wait=True, sleep=10, max_conn=default_max_conn, **kwargs):
         """
         Make the request for the data in a JSOC response and wait for it to be
         staged and then download the data.
@@ -519,7 +521,7 @@ class JSOCClient(BaseClient):
                                 wait=wait, max_conn=max_conn, **defaults)
 
     def get_request(self, requests, path=None, overwrite=False, progress=True,
-                    downloader=None, wait=True, max_conn=4, **kwargs):
+                    downloader=None, wait=True, max_conn=default_max_conn, **kwargs):
         """
         Query JSOC to see if the request(s) is ready for download.
 
@@ -602,9 +604,10 @@ class JSOCClient(BaseClient):
 
         if max_conn * kwargs['max_splits'] > 10:
             warnings.warn(("JSOC does not support more than 10 parallel connections. " +
-                           "Changing the number of parallel connections to 8."), SunpyUserWarning)
+                           f"Changing the number of parallel connections to {2 * self.default_max_conn}."),
+                          SunpyUserWarning)
             kwargs['max_splits'] = 2
-            max_conn = 4
+            max_conn = self.default_max_conn
 
         dl_set = True
         if not downloader:
