@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 import re
 
 import pytest
 
-from sunpy.net import base_client, vso, jsoc, dataretriever
+from sunpy.net import base_client, dataretriever, jsoc, vso
 
 _REGEX = re.compile(r"Client")
 
@@ -20,6 +19,7 @@ CLIENT_LIST.remove(dataretriever.client.GenericClient)
 CLIENT_NAMES = base_client.BaseClient._registry.keys()
 CLIENTS_REG = base_client.BaseClient._registry.items()
 
+
 @pytest.mark.parametrize("client", CLIENT_LIST)
 def test_registry(client):
     """
